@@ -1,9 +1,9 @@
 
-from messytables.util import offset_processor
+from messytables.util import offset_processor, null_processor
 from messytables.headers import headers_guess, headers_processor, headers_make_unique
 from messytables.types import type_guess, types_processor
 from messytables.types import StringType, IntegerType, FloatType, \
-        DecimalType, DateType, DateUtilType
+        DecimalType, DateType, DateUtilType, BoolType
 from messytables.error import ReadError
 
 from messytables.core import Cell, TableSet, RowSet, seekable_stream
