@@ -123,7 +123,7 @@ class CSVRowSet(RowSet):
         sample = delim.join(self._sample)
         try:
             dialect = csv.Sniffer().sniff(sample,
-                delimiters=['\t', ',', ';'])
+                delimiters=['\t', ',', ';', '|'])
             dialect.lineterminator = delim
             dialect.doublequote = True
             return dialect
